"use strict";
/* eslint-disable no-use-before-define */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDoDevopsCommand = exports.isDynamicCommandDefinition = exports.isCommandDescriptor = void 0;
const common_types_1 = require("common-types");
/**
 * Type guard which tests whether the input is a `ICommandDescriptor` dictionary
 */
function isCommandDescriptor(desc) {
    return common_types_1.isNonNullObject(desc) &&
        desc.short &&
        desc.complete
        ? true
        : false;
}
exports.isCommandDescriptor = isCommandDescriptor;
/**
 * **isDynamicCommandDefinition**
 *
 * Tests whether one of the command's meta properties is defined by a
 * `DynamicCommandDefinition` and needs to be _run_ before resolving to
 * it's final value.
 */
function isDynamicCommandDefinition(defn) {
    return typeof defn === "function";
}
exports.isDynamicCommandDefinition = isDynamicCommandDefinition;
/**
 * a type guard which detects a valid shape for the `do-devops` command definition
 */
function isDoDevopsCommand(cmd) {
    return (typeof cmd === "object" &&
        typeof cmd.handler === "function" &&
        typeof cmd.kind === "string" &&
        cmd.description !== undefined);
}
exports.isDoDevopsCommand = isDoDevopsCommand;
