"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const async_shelljs_1 = require("async-shelljs");
const serverless_1 = require("../../shared/serverless/index");
const index_1 = require("./index");
const observations_1 = require("../../shared/observations/index");
const npm_1 = require("../../shared/npm/index");
const core_1 = require("../../shared/core/index");
async function functionDeploy(fns, meta) {
    const { stage } = meta;
    console.log(chalk_1.default `- {bold serverless} deployment for {bold ${String(fns.length)}} functions to {italic ${stage}} stage ${"\uD83C\uDF89" /* party */}`);
    const transpile = index_1.isTranspileNeeded(meta);
    if (transpile.length > 0) {
        // const build = (await import("../../commands/build/util/tools/webpack")).default({
        //   opts: { fns: transpile },
        // }).build;
        // await build();
    }
    console.log(chalk_1.default `{grey - zipping up ${String(fns.length)} {bold Serverless} {italic handler} functions }`);
    await serverless_1.zipWebpackFiles(fns);
    console.log(chalk_1.default `{grey - all handlers zipped; ready for deployment ${"\uD83D\uDC4D" /* thumbsUp */}}`);
    console.log(chalk_1.default `- deploying {bold ${String(fns.length)} functions} to "${stage}" stage`);
    // const sandboxStage = stage === "dev" ? await sandbox(stage) : stage;
    // if (sandboxStage !== stage) {
    // }
    for (const fn of fns) {
        console.log(chalk_1.default.grey(`    - ${fn}`));
    }
    const promises = [];
    try {
        fns.map((fn) => {
            promises.push(async_shelljs_1.asyncExec(`sls deploy function --force --aws-s3-accelerate --function ${fn} --stage ${stage}`));
        });
        await Promise.all(promises);
        console.log(chalk_1.default `\n- all {bold ${String(fns.length)}} function(s) were deployed! ${"\uD83D\uDE80" /* rocket */}\n`);
    }
    catch (error) {
        console.log(chalk_1.default `- {red {bold problems deploying functions!}} ${"\uD83D\uDCA9" /* poop */}`);
        console.log(`- ${error.message}`);
        console.log(chalk_1.default `- {dim ${error.stack}}`);
    }
}
async function fullDeploy(meta) {
    const { stage, config } = meta;
    console.log(chalk_1.default `- Starting {bold FULL serverless} deployment for {italic ${stage}} stage`);
    if (!npm_1.hasDevDependency("serverless-webpack")) {
        console.log(chalk_1.default `{grey - checking timestamps to determine what {bold webpack} transpilation is needed}`);
        // const transpile = isTranspileNeeded(meta);
        // if (transpile.length > 0) {
        //   const build = (await import("../../commands/build/util/tools/webpack")).default({
        //     opts: { fns: transpile },
        //   }).build;
        //   await build();
        // }
        const fns = serverless_1.getLocalHandlerInfo().map((i) => i.fn);
        console.log(chalk_1.default `{grey - zipping up all ${String(fns.length)} Serverless handlers}`);
        await serverless_1.zipWebpackFiles(fns);
        console.log(chalk_1.default `{grey - all handlers zipped; ready for deployment ${"\uD83D\uDC4D" /* thumbsUp */}}`);
    }
    if (config.showUnderlyingCommands) {
        console.log(chalk_1.default `{grey > {italic sls deploy --aws-s3-accelerate  --stage ${stage} --verbose}}\n`);
        try {
            await async_shelljs_1.asyncExec(`sls deploy --aws-s3-accelerate  --stage ${stage} --verbose`);
            console.log(chalk_1.default `\n- The full deploy was successful! ${"\uD83D\uDE80" /* rocket */}\n`);
        }
        catch {
            console.log(chalk_1.default `- {red Error running deploy!}`);
            console.log(chalk_1.default `- NOTE: {dim if the error appears related to running out of heap memory then you can try {bold {yellow export NODE_OPTIONS=--max_old_space_size=4096}}}\n`);
        }
    }
}
/**
 * Manages the execution of a serverless deployment
 */
async function serverlessDeploy(argv, opts) {
    const stage = await observations_1.determineStage({ ...opts, interactive: true });
    if (!stage) {
        console.log(`- AWS stage could not be determined; try using "--stage" option`);
        process.exit();
    }
    const { deploy: config } = await core_1.getIntegratedConfig();
    const meta = {
        stage,
        config: config,
        opts,
    };
    // argv values indicate function deployment
    await (argv.length > 0 ? functionDeploy(argv, meta) : fullDeploy(meta));
}
exports.default = serverlessDeploy;
