"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.watchHandler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const processFiles_1 = require("./processFiles");
const file_1 = require("../../../shared/file/index");
const util_1 = require("./util/index");
const ui_1 = require("../../../shared/ui/index");
/** to avoid circular events, we need to allow certain files to be ignored */
let filesToIgnore = [];
/**
 * configures a watch handler for an `autoindex` watched directory
 */
function watchHandler(dir, options = {}) {
    const log = console.log.bind(console);
    return (evtBeingWatched) => {
        return (filepath) => {
            if (filesToIgnore.includes(filepath)) {
                // autoindex file has been changed due to the autoindex processing itself
                // TODO: why are we removing this from files to ignore?
                filesToIgnore = filesToIgnore.filter((i) => i !== filepath);
                return;
            }
            /** files in event directory which are autoindex files */
            let indexFiles;
            // eslint-disable-next-line unicorn/consistent-function-scoping
            const fileIsIndexFile = (fp) => /(index|private).[jt]s/.test(fp);
            if (fileIsIndexFile(filepath)) {
                filesToIgnore.push(filepath);
                indexFiles = [filepath];
            }
            else {
                indexFiles = file_1.directoryFiles(dir)
                    .map((i) => path_1.default.posix.join(dir, i.file))
                    .filter((f) => util_1.isAutoindexFile(f));
                filesToIgnore = [...filesToIgnore, ...indexFiles];
            }
            // test for lerna monorepo
            const re = /.*packages\/(\S+?\/)/;
            const [_, pkg] = re.exec(filepath) || [undefined, undefined];
            const message = pkg
                ? chalk_1.default `- the file ${ui_1.highlightFilepath(filepath)} in package {italic ${pkg}} was {italic ${evtBeingWatched}} to a watched directory`
                : chalk_1.default `- the file ${ui_1.highlightFilepath(filepath)} was {italic ${evtBeingWatched}} to a watched directory`;
            if (!fileIsIndexFile(filepath)) {
                log(message);
            }
            else {
                if (evtBeingWatched === "unlinked") {
                    indexFiles = [];
                }
            }
            if (indexFiles.length > 0) {
                processFiles_1.processFiles(indexFiles, { ...options, quiet: true }).then(() => log());
            }
        };
    };
}
exports.watchHandler = watchHandler;
