"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const aws_1 = require("../../../shared/aws/index");
const private_1 = require("../private/index");
const handler = async ({ unknown: argv, opts }) => {
    const profiles = await aws_1.getAwsProfileDictionary();
    const profileNames = Object.keys(profiles);
    let chosen = [];
    if (!profiles) {
        console.log(chalk_1.default `- ${"\uD83E\uDD16" /* robot */} you do not have {italic any} AWS profiles in your credentials file!\n`);
        process.exit();
    }
    if (opts.all) {
        chosen = profileNames;
    }
    else if (argv.length === 0) {
        chosen = await private_1.askUser(Object.keys(profiles));
    }
    else {
        chosen = argv.filter((i) => profileNames.includes(i));
        if (chosen.length === 0) {
            console.log(chalk_1.default `- there were {red no} valid profiles provided!`);
            console.log(chalk_1.default `- valid profile names are: {blue ${profileNames.join(", ")}`);
        }
        if (chosen.length !== argv.length) {
            console.log(chalk_1.default `- some profiles provided were not valid; valid ones are listed below`);
        }
    }
    const results = [];
    const errors = [];
    for (const profile of chosen) {
        try {
            results.push({ profile, ...(await aws_1.getAwsIdentityFromProfile(profiles[profile])) });
            process.stdout.write(chalk_1.default `{green .}`);
        }
        catch (error) {
            errors.push({ ...error, profile });
            process.stdout.write(chalk_1.default `{red .}`);
        }
    }
    console.log();
    console.log(results);
    if (errors.length > 0) {
        console.log(chalk_1.default `- there ${errors.length === 1 ? "was" : "were"} ${errors.length} profile${errors.length === 1 ? "" : "s"} which encountered errors trying to authenticate, the rest were fine.`);
        for (const e of errors) {
            console.log(chalk_1.default `- {bold {red ${e.profile}}}: {grey ${e.message}}`);
        }
    }
};
exports.handler = handler;
