"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.defaultConfig = void 0;
const chalk_1 = __importDefault(require("chalk"));
const proxyToPackageManager_1 = require("../../../shared/core/proxyToPackageManager");
const interactive_1 = require("../../../shared/interactive/index");
const npm_1 = require("../../../shared/npm/index");
exports.defaultConfig = {
    preBuildHooks: ["clean"],
    targetDirectory: "dist",
    buildTool: "tsc",
};
const handler = async ({ observations, raw }) => {
    const serverless = observations.has("serverlessFramework");
    if (serverless) {
        if (!observations.has("serverlessTs")) {
            console.log(chalk_1.default `{bold - in order to use the {yellow Serverless Devops} commands, you'll need to have a {blue serverless.ts} file in the root of your repo}`);
            console.log(chalk_1.default `{gray - to find more about this please refer to the docs: https://aws-orchestrate.com/devops}`);
            process.exit();
        }
        if (!observations.has("tsNode")) {
            console.log(chalk_1.default `{bold - the handoff between your configuration in {blue serverless.ts} and the {yellow Serverless Devops} framework requires that you have {blue ts-node} installed as a dev dependency}`);
            const answer = await interactive_1.askConfirmQuestion("Add this dev dep?");
            if (answer) {
                const success = await npm_1.installDevDep(observations, "ts-node");
                if (!success) {
                    process.exit();
                }
            }
            else {
                process.exit();
            }
        }
        console.log(chalk_1.default `{bold {yellow - Starting SERVERLESS build process}}\n`);
        // await buildLambdaTypescriptProject(opts, config);
    }
    else {
        await proxyToPackageManager_1.proxyToPackageManager("build", observations, raw);
    }
    process.exit();
};
exports.handler = handler;
