"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
/* eslint-disable unicorn/import-style */
const aws_1 = require("../../../shared/aws/index");
const observations_1 = require("../../../shared/observations/index");
const table_1 = require("table");
const chalk_1 = __importDefault(require("chalk"));
const handler = async ({ opts }) => {
    const profileName = opts.profile ? opts.profile : await observations_1.determineProfile(opts);
    if (!profileName) {
        console.log(`- couldn't determine the AWS profile to use; try setting it manually with ${chalk_1.default.inverse(" --profile ")} option or switch to interactive mode with ${chalk_1.default.inverse(" --interactive ")}\n`);
        process.exit(1);
    }
    const region = opts.region ? opts.region : await observations_1.determineRegion(opts);
    try {
        console.log(chalk_1.default `- getting API {italic endpoints} for the profile {bold  ${profileName}} [ ${region} ]`);
        // const endpoints = await getLambdaFunctions(opts);
        if (region) {
            const response = await aws_1.getApiGatewayEndpoints(profileName, region);
            console.log({ response });
            const restApi = response.restApi?.items
                ? response.restApi.items.map((i) => {
                    return [i.id, i.name || "", i.description || ""];
                })
                : [];
            const httpApi = response.httpApi?.Items
                ? response.httpApi.Items.map((i) => {
                    return [
                        i.ApiId || "",
                        i.Name || "",
                        i.ApiEndpoint || "",
                        i.CorsConfiguration?.AllowMethods?.join(", ") || "None",
                        i.CorsConfiguration?.AllowOrigins?.join(", ") || "unknown",
                    ];
                })
                : [];
            if (restApi.length > 0) {
                console.log("\nREST API Endpoints");
                console.log(table_1.table([...[["id", "name", "description"]], ...restApi]));
                console.log();
            }
            else {
                console.log(chalk_1.default `{gray - no REST API endpoints found}`);
                console.log();
            }
            if (httpApi.length > 0) {
                console.log("HTTP API Endpoints");
                const t = [...[["id", "name", "endpoint", "methods", "origins"]], ...httpApi];
                console.log(table_1.table(t));
            }
        }
        else {
            console.log(`- could not determine ${chalk_1.default.bold.yellow("AWS region")}; try using ${chalk_1.default.inverse(" --region ")} option to set it explicitly\n`);
        }
    }
    catch { }
};
exports.handler = handler;
