"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.functionsLocalTable = exports.functionsApiTable = void 0;
const chalk_1 = __importDefault(require("chalk"));
const ui_1 = require("../../../shared/ui/index");
function functionsApiTable(fns) {
    return ui_1.toTable(fns, {
        col: "FunctionName",
        name: "Function",
        formula: (f) => chalk_1.default `{dim ${String(f).split("-").slice(0, -1).join("-")}-}{bold ${String(f)
            .split("-")
            .slice(-1)}}`,
        format: { width: 45, alignment: "left" },
    }, {
        col: "MemorySize",
        name: "Memory",
        format: { width: 8, alignment: "center" },
        minWidth: 104,
    }, {
        col: "CodeSize",
        name: "Code Size",
        formula: (cs) => chalk_1.default `${Math.floor(Number(cs) / 10000) * 10} {italic kb}`,
        format: { width: 12, alignment: "right" },
        minWidth: 130,
    }, {
        col: "Timeout",
        formula: (t) => `${t}s`,
        format: { width: 8, alignment: "right" },
        minWidth: 123,
    }, {
        col: "Layers",
        formula: (i) => Array.isArray(i)
            ? i.map((i) => i?.Arn.split(":").slice(-2).join(":") || "").join("\n")
            : "",
        format: { width: 20, alignment: "center" },
        minWidth: 155,
    }, {
        col: "Description",
        format: { width: 42, alignment: "left", wrapWord: true },
    });
}
exports.functionsApiTable = functionsApiTable;
function functionsLocalTable(fns) {
    return ui_1.toTable(fns, {
        col: "name",
        name: "Function",
        formula: (f) => chalk_1.default `{dim ${String(f).split("-").slice(0, -1).join("-")}-}{bold ${String(f)
            .split("-")
            .slice(-1)}}`,
        format: { width: 45, alignment: "left" },
    }, {
        col: "memorySize",
        name: "Memory",
        formula: (m) => (m ? m : chalk_1.default.grey("1024")),
        format: { width: 8, alignment: "center" },
        minWidth: 104,
    }, {
        col: "timeout",
        name: "Timeout",
        formula: (t) => (t ? `${t}s` : chalk_1.default.gray("3s")),
        format: { width: 8, alignment: "right" },
        minWidth: 123,
    }, {
        col: "events",
        name: "Events",
        formula: (events) => Array.isArray(events) ? events.map((evt) => Object.keys(evt)) : [],
        format: { width: 20, alignment: "center" },
        minWidth: 155,
    }, {
        name: "Description",
        col: "description",
        formula: (d) => (d ? d : chalk_1.default.italic.dim("no description")),
        format: { width: 42, alignment: "left", wrapWord: true },
    });
}
exports.functionsLocalTable = functionsLocalTable;
