"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
/* eslint-disable quotes */
const chalk_1 = __importDefault(require("chalk"));
const async_shelljs_1 = require("async-shelljs");
const serverless_1 = require("../../../shared/serverless/index");
const observations_1 = require("../../../shared/observations/index");
const file_1 = require("../../../shared/file/index");
const interactive_1 = require("../../../shared/interactive/index");
const core_1 = require("../../../shared/core/index");
const handler = async ({ observations, opts, unknown: argv, raw, }) => {
    if (!observations.has("serverlessFramework")) {
        await core_1.proxyToPackageManager("invoke", observations, raw);
        process.exit();
    }
    try {
        const sls = await observations_1.isServerless();
        if (!sls) {
            console.log(chalk_1.default `{red - This project is not configured as a {bold Serverless} project!} ${"\uD83D\uDE21" /* angry */}\n`);
            process.exit();
        }
        if (argv.length > 1) {
            console.log(chalk_1.default `{dim - you have stated more than one function to {italic invoke}.}`);
            console.log(chalk_1.default `{dim - this command only executes one at a time; the rest are ignored.}`);
        }
        let fn;
        if (argv.length === 0) {
            fn = await serverless_1.askForFunction();
        }
        else {
            fn = argv[0];
            const availableFns = Object.keys((await serverless_1.getLocalServerlessFunctionsFromServerlessYaml()) || {});
            if (!availableFns.includes(fn)) {
                console.log(chalk_1.default `{red - The function "{white ${fn}}" is not a valid function!} ${"\uD83D\uDE32" /* shocked */}`);
                console.log("- valid functions are:");
                console.log(chalk_1.default `{dim   - ${availableFns.join("\n  - ")}}`);
                process.exit();
            }
        }
        let data;
        if (opts.data) {
            try {
                data = await file_1.readDataFile(opts.data, "json");
            }
            catch {
                const possible = await file_1.getDataFiles({
                    filterBy: opts.data,
                });
                if (possible.length > 1) {
                    data = await interactive_1.askForDataFile(possible);
                }
                else if (possible.length === 1) {
                    data = await file_1.readDataFile(possible[0]);
                }
                else {
                    console.log(chalk_1.default `{red - Data file "${opts.data}" not found!}`);
                    data = await interactive_1.askForDataFile();
                }
            }
        }
        if (opts.interactive) {
            data = await interactive_1.askForDataFile();
        }
        if (!opts.quiet) {
            console.log(chalk_1.default `{grey > sls invoke local --function {dim {white ${fn}}} --data '{dim {white ${data}}}'}`);
        }
        await async_shelljs_1.asyncExec(`sls invoke local --function ${fn} --data '${data}'`);
    }
    catch (error) {
        console.log(`- Error finding functions: ${error.message}\n`);
        process.exit();
    }
};
exports.handler = handler;
