"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const git_1 = require("../../../shared/git/index");
const npm_1 = require("../../../shared/npm/index");
const handler = async ({ opts }) => {
    const g = git_1.git();
    const latest = (await g.tags()).latest;
    const status = await g.status();
    const pkg = npm_1.getPackageJson();
    if (!pkg) {
        console.log(`- the "latest" command provides you with the latest version of the repo in the {italic current} directory`);
        console.log(`   however it appears you're in directory without a package.json file! ${"\uD83D\uDE32" /* shocked */}\n`);
        console.log(chalk_1.default `- please move to a new directory or pass in the optional '--repo [repo]' parameter to name a repo`);
        process.exit();
    }
    const pkgVersion = pkg.version;
    const aheadBehind = status.ahead === 0 && status.behind === 0
        ? ""
        : `\n- Your local repo is ${status.ahead > 0
            ? `ahead by ${status.ahead} commits`
            : `behind by ${status.behind} commits`}`;
    const changes = status.not_added.length === 0 && status.modified.length === 0
        ? ""
        : chalk_1.default `\n- Locally you have {yellow ${status.not_added.length > 0 ? status.not_added.length : "zero"}} {italic new} files and {yellow ${status.modified.length}} {italic modified} files`;
    const conflicts = status.conflicted.length === 0
        ? ""
        : chalk_1.default `- ${"\uD83D\uDCA9" /* poop */} There are {bold {red ${status.conflicted.length}}} conflicted files!`;
    if (opts.verbose) {
        console.log(chalk_1.default `The remote repo's latest version is {bold {yellow ${latest}}}; {blue package.json} is ${pkgVersion === latest ? "the same" : `is {bold ${pkgVersion}}`}.${aheadBehind}${changes}${conflicts}`);
        console.log("\n");
    }
    else {
        console.log(latest);
    }
    return latest;
};
exports.handler = handler;
