"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const ui_1 = require("../../../shared/ui/index");
const serverless_1 = require("../../../shared/serverless/index");
const META_LINK_MSG = chalk_1.default `{dim - the results rely on meta-data tagging; check out this link for more info:\n      {blueBright https://github.com/inocan-group/do-devops/docs/layer-meta.md}}\n`;
/** handler for the "layers" command */
const handler = async ({ observations }) => {
    if (observations.has("serverlessFramework")) {
        const layers = serverless_1.getLayersFromPackageJson();
        if (layers.length > 0) {
            console.log(ui_1.toTable(layers, { col: "name", format: { width: 30, alignment: "left" } }, {
                col: "versions",
                formula: (v) => (Array.isArray(v) ? v.pop()?.version || "unknown" : v || "unknown"),
                format: { width: 7, alignment: "center" },
            }, { col: "description", format: { width: 64, alignment: "left", wrapWord: true } }));
            console.log(META_LINK_MSG);
        }
        else {
            console.log(chalk_1.default `- there were {italic no} layers found as dependencies to this repo`);
            console.log(META_LINK_MSG);
        }
    }
    else {
        console.log(chalk_1.default `- the current directory is not a Serverless repo\n`);
    }
};
exports.handler = handler;
