"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const async_shelljs_1 = require("async-shelljs");
const deploy_helpers_1 = require("../../../_archive/deploy-helpers/index");
const observations_1 = require("../../../shared/observations/index");
/**
 * **Package Handler**
 *
 * The `package` command is used in **Serverless** projects to build all of
 * the _deployable_ assets but without actually deploying.
 */
const handler = async ({ opts }) => {
    // const { pkg } = await getConfig();
    const detect = await deploy_helpers_1.detectTarget();
    const target = detect.target;
    const stage = await observations_1.determineStage(opts);
    const region = await observations_1.determineRegion(opts);
    if (!target) {
        console.log(`  - ${"\uD83D\uDCA9" /* poop */} You must state a valid "target" [ ${target ? target + "{italic not valid}" : "no target stated"} ]`);
    }
    console.log(chalk_1.default `- {bold Serverless} {italic packaging} for {bold ${stage}} stage ${"\uD83C\uDF89" /* party */}`);
    const command = `sls package --stage ${stage} --region ${region} ${opts.dir ? `--package ${opts.dir}` : ""}`;
    console.log(chalk_1.default `{dim {italic ${command}}}\n`);
    await async_shelljs_1.asyncExec(command, { silent: opts.quiet ? true : false });
    const directory = opts.dir ? opts.dir : ".serverless";
    console.log(chalk_1.default `\n{bold {green - Packaging is complete!}} ${"\uD83D\uDE80" /* rocket */}`);
    console.log(chalk_1.default `- the assets can all be found in the {italic {blue ${directory}} directory.}`);
    await async_shelljs_1.asyncExec(`ls -l ${directory}`);
    if (opts.validate) {
        console.log(chalk_1.default `\n- validating the {bold cloudformation} {italic create} template ${"\uD83D\uDC40" /* eyeballs */}`);
        const validateCmd = `aws cloudformation validate-template --template-body file://${directory}/cloudformation-template-create-stack.json`;
        try {
            console.log(chalk_1.default `{dim    ${validateCmd}}`);
            await async_shelljs_1.asyncExec(validateCmd);
        }
        catch {
            console.log(chalk_1.default `{red - Error validating the {italic create} template!}`);
        }
        console.log(chalk_1.default `\n- validating the {bold cloudformation} {italic update} template ${"\uD83D\uDC40" /* eyeballs */}`);
        const validateUpdate = `aws cloudformation validate-template --template-body file://${directory}/cloudformation-template-update-stack.json`;
        try {
            console.log(chalk_1.default `{dim    ${validateUpdate}}`);
            await async_shelljs_1.asyncExec(validateUpdate);
        }
        catch {
            console.log(chalk_1.default `{red - Error validating the {italic update} template!} ${"\uD83D\uDCA9" /* poop */}`);
        }
    }
    // await runHooks(deploy.preDeployHooks);
};
exports.handler = handler;
