"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const chalk_1 = __importDefault(require("chalk"));
const serverless_1 = require("../../../shared/serverless/index");
const private_1 = require("../private/index");
const handler = async (input) => {
    const { subCommand, observations } = input;
    const validSubCommands = ["list", "get", "set"];
    if (!subCommand) {
        console.log(chalk_1.default `- the SSM command requires you pick a valid sub-command; choose from: {italic ${validSubCommands.join(", ")}}`);
        process.exit();
    }
    if (!validSubCommands.includes(subCommand)) {
        console.log(`- please choose a ${chalk_1.default.italic("valid")} ${chalk_1.default.bold.yellow("SSM")} sub-command: ${Object.keys(private_1.subCommands).join(", ")}`);
        console.log();
        process.exit();
    }
    const serverless = observations.has("serverlessFramework") && observations.has("serverlessTs");
    if (serverless) {
        await serverless_1.buildLambdaTypescriptProject();
    }
    try {
        await private_1.subCommands[subCommand].execute(input);
    }
    catch (error) {
        console.log(chalk_1.default `{red - Ran into error when running "ssm ${subCommand}":}\n  - ${error.message}\n`);
        console.log(chalk_1.default `{grey - ${error.stack}}`);
        process.exit(1);
    }
};
exports.handler = handler;
