"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.completeSsmName = void 0;
const chalk_1 = __importDefault(require("chalk"));
const errors_1 = require("../../../errors/index");
const interactive_1 = require("../../../shared/interactive/index");
function nameToUpper(parts) {
    return [...parts.slice(0, -1), parts.slice(-1)[0].toUpperCase()].join("/");
}
/**
 * Generates the name of the SSM variable where the user typically just puts in the core name
 * and the stage and version must be determined.
 *
 * @param name
 * @param hints
 */
async function completeSsmName(name, hints = {}) {
    const parts = name.split("/");
    const lastIsUpper = parts.slice(-1)[0].toUpperCase() === parts.slice(-1)[0];
    if (!lastIsUpper) {
        console.log(chalk_1.default `\n- The last component of the name is intended -- {italic by convention} -- to be UPPERCASE.\n  Therefore we will convert your name to ${nameToUpper(parts)} with your permission.\n`);
        const cont = await interactive_1.askConfirmQuestion("Continue?");
        if (!cont) {
            console.log();
            process.exit();
        }
    }
    if (parts.length === 2) {
        // we just got the type/SUB_TYPE so add in stage and version from hints or default to sensible defaults
        return `/${hints.stage || "dev"}/${hints.version || 1}/${nameToUpper(parts)}`;
    }
    if (parts.length > 2) {
        if (Number.isInteger(parts[1])) {
            return nameToUpper(parts);
        }
        else {
            console.log(chalk_1.default `\nThe SSM variable {italic name} does not appear to be correctly formatted. The format\nshould be:\n`);
            console.log(chalk_1.default `/{dim [stage]}/{dim [version]}/{dim [moduleName]}/{dim [VAR NAME]}\n`);
            console.log(chalk_1.default `In most cases the best strategy is just to state the module name and final\nvariable name and let the autocomplete do the rest.`);
            throw new errors_1.DevopsError("Incorrect SSM variable formatting", "ssm/invalid-format");
        }
    }
    throw new errors_1.DevopsError("Incorrect SSM variable structure", "ssm/invalid-structure");
}
exports.completeSsmName = completeSsmName;
