"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = void 0;
const chalk_1 = __importDefault(require("chalk"));
const process_1 = __importDefault(require("process"));
const date_fns_1 = require("date-fns");
const table_1 = require("table");
const aws_ssm_1 = require("aws-ssm");
const aws_1 = require("../../../../shared/aws/index");
const observations_1 = require("../../../../shared/observations/index");
const execute = async ({ opts, observations, unknown: argv, }) => {
    const profile = await observations_1.determineProfile({ ...opts, interactive: true }, observations);
    if (!profile) {
        console.log(chalk_1.default `- Couldn't determine the AWS Profile; try setting it manually with {inverse  --profile }.`);
        console.log(chalk_1.default `- alternatively use the {inverse --interactive } option to have the CLI interactively let you select`);
        process_1.default.exit();
    }
    const profileInfo = await aws_1.getAwsProfile(profile);
    const region = opts.region || profileInfo.region || (await observations_1.determineRegion({ ...opts, interactive: true }));
    const filterBy = argv.length > 0 ? argv[0] : undefined;
    if (!profile || !region) {
        console.log(chalk_1.default `{red - missing information!}`);
        console.log(chalk_1.default `To list SSM params the AWS {italic profile} and {italic region} must be stated. These could {bold not} be determined so exiting.`);
        console.log(chalk_1.default `{dim note that the easiest way to get an explicit profile/region is to use the {bold --profile} and {bold --region} switches on the command line.}\n`);
        process_1.default.exit();
    }
    if (!opts.quiet) {
        console.log(`- Listing SSM parameters in profile "${chalk_1.default.bold(profile)}", region "${chalk_1.default.bold(region)}"${filterBy ? `; results reduced to those with "${chalk_1.default.bold(filterBy)}" in the name.` : ""}`);
        console.log();
    }
    const ssm = new aws_ssm_1.SSM({
        profile,
        region,
    });
    const list = await ssm.describeParameters();
    const tableData = [
        [
            chalk_1.default.bold("Name"),
            chalk_1.default.bold("Version"),
            chalk_1.default.bold("Type"),
            chalk_1.default.bold("LastModified"),
            chalk_1.default.bold("User"),
        ],
    ];
    for (const i of list.filter((i) => !filterBy || (i.Name || "").includes(filterBy))) {
        tableData.push([
            i.Name || "",
            String(i.Version),
            i.Type || "",
            i.LastModifiedDate ? date_fns_1.format(i.LastModifiedDate, "dd MMM, yyyy") : "",
            i.LastModifiedUser ? i.LastModifiedUser.replace(/.*user\//, "") : "",
        ]);
    }
    const tableConfig = {
        columns: {
            0: { width: 42, alignment: "left" },
            1: { width: 8, alignment: "center" },
            2: { width: 14, alignment: "center" },
            3: { width: 18, alignment: "center" },
            4: { width: 14 },
        },
    };
    console.log(table_1.table(tableData, tableConfig));
};
exports.execute = execute;
