"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = void 0;
const aws_1 = require("../../../../shared/aws/index");
const chalk_1 = __importDefault(require("chalk"));
const aws_ssm_1 = require("aws-ssm");
const index_1 = require("../index");
const native_dash_1 = require("native-dash");
const observations_1 = require("../../../../shared/observations/index");
const serverless_1 = require("../../../../shared/serverless/index");
const execute = async ({ opts, unknown: argv }) => {
    if (argv.length < 2) {
        console.log(chalk_1.default `The "dd ssm set" command expects the variable name and value as parameters on the command line: {blue {bold do ssm set} <{italic name}> <{italic value}>}\n`);
        console.log(chalk_1.default `{grey {bold - Note:} you can include a {italic partial name} for the variable and things like the AWS profile, region, stage, and version number\n  will be filled in where possible}\n`);
        process.exit(1);
    }
    let [name, value] = argv;
    const profile = await observations_1.determineProfile({ ...opts, interactive: true });
    if (!profile) {
        console.log(chalk_1.default `- Couldn't determine the AWS Profile; try setting it manually with {inverse  --profile }.`);
        console.log(chalk_1.default `- alternatively use the {inverse --interactive } option to have the CLI interactively let you select`);
        process.exit();
    }
    const profileInfo = await aws_1.getAwsProfile(profile);
    const identity = await aws_1.getAwsIdentityFromProfile(profileInfo);
    const region = opts.region || profileInfo.region || (await observations_1.determineRegion(opts));
    const stage = opts.stage ||
        process.env.AWS_STAGE ||
        process.env.NODE_ENV ||
        (await serverless_1.askForStage(chalk_1.default `SSM variables should be namespaced to a STAGE, what stage are you setting for {dim [ profile: {italic ${profile}}, region: {italic ${region}}, account: {italic ${identity.accountId}} ]}?`));
    const ssm = new aws_ssm_1.SSM({ profile, region });
    name = await index_1.completeSsmName(name, { stage });
    if (opts.base64) {
        value = native_dash_1.toBase64(value);
    }
    process.env.AWS_STAGE = stage;
    try {
        await ssm.put(name, value, {
            description: opts.description,
            override: opts.force,
        });
        console.log(chalk_1.default `\n- ${"\uD83C\uDF89" /* party */} the {bold {yellow ${name}}} variable was set successfully to the {italic ${region}} region {dim [ profile: {italic ${profile}}, region: {italic ${region}}, account: {italic ${identity.accountId}} ]}\n`);
    }
    catch (error) {
        console.log();
        if (error.code === "ParameterAlreadyExists") {
            console.log(chalk_1.default `- {red {bold Paramater Already Exists!}} to overwrite a parameter which already exists you must add {blue --force} to the CLI command`);
        }
        else {
            console.log(chalk_1.default `{red {bold Error:}} ${error.message}`);
        }
        console.log();
        process.exit(1);
    }
};
exports.execute = execute;
