"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.askForUnitTestFramework = void 0;
const chalk_1 = __importDefault(require("chalk"));
const constants_1 = require("../../../constants");
const interactive_1 = require("../../../shared/interactive/index");
/**
 * A user ends up here if:
 *
 * - they've run `dd build` but never run the command before in the repo
 * - they do they have _hints_ in terms of dev dependencies about what tool is being used
 * - basically we can assume that the user has a pretty clean slate wrt to testing
 * but that they _do_ have a package.json file.
 */
async function askForUnitTestFramework() {
    // const pkg = getPackageJson();
    // const devDeps = Object.keys(pkg.devDependencies || {});
    const fwChoices = [...constants_1.TEST_FRAMEWORKS, "quit"];
    console.log(chalk_1.default `- we have not been able to determine which {italic unit testing} framework you're using.`);
    const framework = interactive_1.listQuestion("fw", "Choose the framework you'd like to use (or 'quit')", fwChoices, "jest");
    const install = interactive_1.confirmQuestion("installed", "Would you like us to install that for you now?");
    const wallaby = interactive_1.confirmQuestion("useWallaby", "Would you like us to add a WallabyJS config file so you can use it as a test runner in this repo?");
    const patterns = [
        "**/*[-.]spec.ts",
        "**/*[-.]test.ts",
        "**/*[-.](test|spec).ts",
        "test/**/*.ts",
        "tests/**/*.ts",
    ];
    const testPatterns = interactive_1.listQuestion("testPattern", "Unit test runners use a regular expression to identify what files are tests; which one do you prefer?", ["SKIP FOR NOW", ...patterns], "**/*[-.]spec.ts");
    const { fw, installed, useWallaby } = await interactive_1.ask([framework, install, wallaby, testPatterns]);
    return {
        fw: fw !== "skip" ? fw : false,
        installed,
        useWallaby,
    };
}
exports.askForUnitTestFramework = askForUnitTestFramework;
