#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const command_line_args_1 = __importDefault(require("command-line-args"));
const process = __importStar(require("process"));
const core_1 = require("./shared/core/index");
const help_1 = require("./shared/core/help");
const ui_1 = require("./shared/ui/index");
const getObserverations_1 = require("./shared/observations/getObserverations");
const util_1 = require("./shared/core/util/index");
(async () => {
    // pull off the command and stop there
    const mainCommand = command_line_args_1.default([{ name: "command", defaultOption: true, type: String }], {
        stopAtFirstUnknown: true,
    });
    const remaining = mainCommand._unknown || [];
    /** the primary command */
    const cmdName = mainCommand.command;
    // undocumented version switch
    if (!cmdName && mainCommand._unknown?.includes("--version")) {
        console.log(util_1.doDevopsVersion());
        process.exit();
    }
    const observations = getObserverations_1.getObservations();
    // undocumented observations switch
    if (!cmdName && mainCommand._unknown?.includes("--observations")) {
        console.log(`Observations:`, [...observations].map((i) => chalk_1.default `{inverse  ${i} }`).join(" "));
        process.exit();
    }
    if (!cmdName) {
        util_1.commandAnnouncement(undefined, undefined, true);
        help_1.help(observations);
        process.exit();
    }
    if (core_1.isKnownCommand(cmdName)) {
        const cmdDefn = core_1.getCommand(cmdName);
        const cmdInput = { ...core_1.parseCmdArgs(cmdDefn, remaining), observations };
        if (cmdInput.opts.help) {
            util_1.commandAnnouncement(cmdDefn, cmdInput.subCommand, true);
            help_1.help(observations, cmdDefn);
            process.exit();
        }
        try {
            util_1.commandAnnouncement(cmdDefn, cmdInput.subCommand);
            await cmdDefn.handler(cmdInput);
            if (cmdInput.unknown && cmdInput.unknown.filter((i) => i).length > 0) {
                const plural = cmdInput.unknown.length === 1 ? false : true;
                const preposition = cmdInput.unknown.length === 1 ? "was" : "were";
                console.log(chalk_1.default `- Note: {italic there ${preposition} ${cmdInput.unknown.length} {italic unknown} parameter${plural ? "s" : ""} received (and ignored): {gray ${cmdInput.unknown.join(", ")}}}`);
            }
        }
        catch (error) {
            console.log(chalk_1.default `\n{red An Error has occurred while running: {italic {bold do-devops ${cmdName}}}}`);
            console.log(`- ${error.message}`);
            console.log(chalk_1.default `{grey   ${error.stack}}\n`);
            process.exit();
        }
    }
    else {
        console.log(`${chalk_1.default.bold.red("Whoops! ")} ${chalk_1.default.italic.yellowBright(cmdName)} is an unknown command! \n\n` +
            `- Valid command syntax is: ${chalk_1.default.bold.inverse(" dd [command] <options> ")}\n  where valid commands are: ${chalk_1.default.italic(core_1.getAllCommands()
                .map((i) => i.kind)
                .sort()
                .join(", "))}\n\n` +
            chalk_1.default `{dim - If you want more help with a specific command, use} ${ui_1.inverted(" dd [cmd] --help ")}\n`);
    }
})();
