"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidServerlessHandlers = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fast_glob_1 = __importDefault(require("fast-glob"));
const path_1 = __importDefault(require("path"));
const parseFile_1 = require("./parseFile");
const file_1 = require("../file/index");
/**
 * Gets a list of all typescript files under the `src/handlers`
 * directory that have a `handlers` export.
 */
function getValidServerlessHandlers() {
    const allFiles = fast_glob_1.default.sync(path_1.default.join(process.env.PWD || "", "/src/handlers/**/*.ts"));
    return allFiles.reduce((agg, curr) => {
        let ast;
        let status = "starting";
        try {
            ast = parseFile_1.parseFile(curr);
            status = "file-parsed";
            if (!ast.program.body[0].source) {
                console.log(chalk_1.default `{grey - the file {blue ${file_1.toRelativePath(curr)}} has no source content; will be ignored}`);
                return agg;
            }
            const loc = ast.program.body[0].source.loc;
            status = "loc-identified";
            const handler = loc.tokens.find((i) => i.value === "handler");
            status = handler ? "handler-found" : "handler-missing";
            if (handler) {
                if (!Array.isArray(agg)) {
                    throw new TypeError(`Found a handler but somehow the file aggregation is not an array! ${handler}`);
                }
                agg.push(curr);
            }
            return agg;
        }
        catch (error) {
            console.log(chalk_1.default `- Error processing  {red ${file_1.toRelativePath(curr)}} [s: ${status}]: {grey ${error.message}}`);
            return agg;
        }
    }, []);
}
exports.getValidServerlessHandlers = getValidServerlessHandlers;
