"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.askForAwsProfile = void 0;
const inquirer_1 = __importDefault(require("inquirer"));
const interactive_1 = require("../interactive/index");
const index_1 = require("./index");
/**
 * Asks the user to choose an AWS profile
 */
async function askForAwsProfile(opts) {
    opts = opts ? { exitOnError: false, ...opts } : { exitOnError: false };
    const profiles = await index_1.getAwsProfileDictionary();
    if (!profiles) {
        const cont = interactive_1.askConfirmQuestion(`Currently you don't have any AWS profiles (aka, profiles in ~/.aws/credentials).\nWould you like to create one now?`);
        if (!cont) {
            console.log(`- no problem, try this command again when you're ready.\n`);
            process.exit();
        }
    }
    const defaultProfile = opts.defaultProfile ? profiles[opts.defaultProfile] : profiles[0];
    const question = {
        name: "profile",
        type: "list",
        choices: Object.keys(profiles),
        message: "choose a profile from your AWS credentials file",
        default: defaultProfile,
        when: () => true,
    };
    const answer = await inquirer_1.default.prompt(question);
    return answer.profile;
}
exports.askForAwsProfile = askForAwsProfile;
