"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertProfileToApiCredential = void 0;
const chalk_1 = __importDefault(require("chalk"));
const errors_1 = require("../../errors/index");
const aws_type_guards_1 = require("./aws-type-guards");
/**
 * **convertProfileToApiCredential**
 *
 * Converts the `IAwsProfile` format (which mimics the snake_case naming you have in the credentials file) and
 * converts it to an `IAwsCredentials` shape which can be used directly in credentializing an
 * API call.
 *
 * **Errors:**
 *   - `do-devops/invalid-aws-profile`
 */
function convertProfileToApiCredential(profile) {
    if (!aws_type_guards_1.isAwsProfile(profile)) {
        const isObject = typeof profile === "object" && profile !== null;
        throw new errors_1.DevopsError(chalk_1.default `The {bold {red IAwsProfile}} information which was passed in to be converted to {bold IAwsCredentials} data was malformed and can not be converted! To be valid a key it must have both {green aws_access_key_id} and {green aws_secret_access_key} defined. [${isObject
            ? "keys found were " + Object.keys(profile).join(", ")
            : `wrong type: ${typeof profile}`}]\n\n`, "do-devops/invalid-aws-profile");
    }
    return {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
    };
}
exports.convertProfileToApiCredential = convertProfileToApiCredential;
