"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAwsDefaultRegion = void 0;
const aws_sdk_1 = require("aws-sdk");
const errors_1 = require("../../errors/index");
const convertProfileToApiCredential_1 = require("./convertProfileToApiCredential");
const getAwsProfile_1 = require("./getAwsProfile");
/**
 * Given a stated AWS profile that exists in a user's credentials file,
 * this function will use the AWS SDK to determine the default region
 * for the profile.
 */
async function getAwsDefaultRegion(profileName) {
    const profile = await getAwsProfile_1.getAwsProfile(profileName);
    const credential = convertProfileToApiCredential_1.convertProfileToApiCredential(profile);
    if (!credential) {
        throw new errors_1.DevopsError(`Could not get the credentials for the profile "${profileName}".`, "not-allowed/no-credentials");
    }
    const api = new aws_sdk_1.EC2({ ...credential });
    return api.describeAvailabilityZones().promise();
}
exports.getAwsDefaultRegion = getAwsDefaultRegion;
