"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAwsLambdaFunctions = void 0;
const aws_sdk_1 = require("aws-sdk");
const index_1 = require("../../errors/index");
const observations_1 = require("../observations/index");
const convertProfileToApiCredential_1 = require("./convertProfileToApiCredential");
const getAwsProfile_1 = require("./getAwsProfile");
/**
 * Gets a list of AWS Lambda functions from a given AWS
 * profile and region. This list is provided using the
 * AWS CLI.
 */
async function getAwsLambdaFunctions(opts) {
    const profile = opts.profile ? opts.profile : await observations_1.determineProfile(opts);
    const region = opts.region ? opts.region : await observations_1.determineRegion(opts);
    if (!profile || !region) {
        throw new index_1.DevopsError(`Requesting a list of AWS functions requires an AWS profile and a specified region. One or both were missing [ p: ${profile}, r: ${region}] `, "not-ready/missing-aws-properties");
    }
    const credentials = convertProfileToApiCredential_1.convertProfileToApiCredential(await getAwsProfile_1.getAwsProfile(profile));
    const lambda = new aws_sdk_1.Lambda({ ...credentials, region });
    return lambda.listFunctions().promise();
}
exports.getAwsLambdaFunctions = getAwsLambdaFunctions;
