"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAwsProfile = void 0;
const index_1 = require("./index");
const index_2 = require("../../errors/index");
/**
 * Get a specific AWS _profile_ in the AWS _credentials_ file.
 *
 * Possible errors:
 *   - `do-devops/invalid-profile-name`
 *   - `do-devops/no-credentials-file`
 */
async function getAwsProfile(profileName) {
    const profile = await index_1.getAwsProfileDictionary();
    if (!profile) {
        throw new index_2.DevopsError(`Attempt to get the AWS profile "${profileName}" failed because the AWS credentials file does not exist!`, "do-devops/no-credentials-file");
    }
    if (!profile[profileName]) {
        throw new index_2.DevopsError(`The AWS profile "${profileName}" does not exist in the AWS credentials file! Valid profile names are: ${Object.keys(profile).join(", ")}`, "do-devops/invalid-profile-name");
    }
    return profile[profileName];
}
exports.getAwsProfile = getAwsProfile;
