"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAwsProfileDictionary = void 0;
const aws_1 = require("./index");
const file_1 = require("../file/index");
/**
 * **getAwsProfileDictionary**
 *
 * Interogates the `~/.aws/credentials` file to get a hash of
 * profiles (name/dictionary of values) the user has available.
 *
 * If the file isn't found then an empty object is returned.
 */
async function getAwsProfileDictionary() {
    try {
        const credentialsFile = aws_1.hasAwsProfileCredentialsFile();
        if (!credentialsFile) {
            return {};
        }
        const data = await file_1.readFile(credentialsFile);
        const targets = ["aws_access_key_id", "aws_secret_access_key", "region"];
        // extracts structured information from the semi-structured
        // array of arrays
        const extractor = (agg, curr) => {
            let profileSection = "unknown";
            for (const lineOfFile of curr) {
                if (lineOfFile.slice(-1) === "]") {
                    profileSection = lineOfFile.slice(0, -1);
                    agg[profileSection] = {};
                }
                for (const t of targets) {
                    if (lineOfFile.includes(t)) {
                        const [_, key, value] = lineOfFile.match(/\s*(\S+)\s*=\s*(\S+)/);
                        agg[profileSection][key] = value;
                    }
                }
            }
            return agg;
        };
        const credentials = data
            ? data
                .split("[")
                .map((i) => i.split("\n"))
                .reduce(extractor, {})
            : {};
        return credentials;
    }
    catch {
        return {};
    }
}
exports.getAwsProfileDictionary = getAwsProfileDictionary;
