"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getIntegratedConfig = void 0;
const deepmerge_1 = __importDefault(require("deepmerge"));
const native_dash_1 = require("native-dash");
const core_1 = require("./index");
/**
 * **getConfig**
 *
 * Gets the current configuration based on the `do.config.js` file.
 *
 * By default the configuration that will be loaded is the project's
 * configuration but you can override to use the `user` config
 * or `both`. In the case of `both`, the two config's will be merged
 * and the project config taking precedence.
 *
 * The lack of a configuration file will not be treated as an error
 * but will instead resolve to an empty object.
 */
function getIntegratedConfig() {
    const userConfig = core_1.getUserConfig();
    const projectConfig = core_1.getProjectConfig();
    if (!userConfig.userConfig && !projectConfig.projectConfig) {
        return { kind: "integrated", ready: false, userConfig: false, projectConfig: false };
    }
    const u = native_dash_1.omit(userConfig, "kind");
    const p = native_dash_1.omit(projectConfig, "kind");
    const merged = deepmerge_1.default(deepmerge_1.default(u, p), {
        kind: "integrated",
        ready: userConfig.userConfig || projectConfig.projectConfig,
    });
    return merged;
}
exports.getIntegratedConfig = getIntegratedConfig;
