"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.help = void 0;
const chalk_1 = __importDefault(require("chalk"));
const command_line_usage_1 = __importDefault(require("command-line-usage"));
const index_1 = require("./index");
const util_1 = require("./util/index");
/**
 * Provide help on **do-devops**, either in a global sense or for a
 * particular function.
 */
function help(observations, cmdDefn) {
    const { kind, subCommands, description, syntax, options } = cmdDefn
        ? util_1.finalizeCommandDefinition(cmdDefn, observations)
        : {
            subCommands: util_1.globalCommandDescriptions(observations),
            description: "do-devops is a set of utility functions designed to make DevOps more fun in less time",
            syntax: "dd [cmd] [options]",
            options: index_1.globalOptions,
        };
    const sections = [
        {
            header: "Description",
            content: description,
        },
        {
            header: "Syntax",
            content: syntax,
        },
    ];
    if (subCommands) {
        sections.push(util_1.formatCommandsSection(subCommands, kind));
    }
    if (kind) {
        sections.push({
            header: "Options",
            optionList: index_1.convertOptionsToArray(options || {}),
        });
    }
    try {
        console.log(command_line_usage_1.default(sections));
    }
    catch (error) {
        console.log(`  - ${"\uD83D\uDCA9" /* poop */}  ${chalk_1.default.red("Problem displaying help:")} ${error.message}\n`);
        console.log(chalk_1.default.grey(error.stack));
    }
    console.log();
    process.exit();
}
exports.help = help;
