"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseCmdArgs = void 0;
const command_line_args_1 = __importDefault(require("command-line-args"));
const index_1 = require("./index");
/**
 * Given a known command to the CLI, this function will
 * parse the command line arguments to arrive at both
 * an `argv` array and `opts` hash to be passed to the
 * command.
 */
function parseCmdArgs(cmd, incomingArgv) {
    // to ensure that what we'd see as "argv" from the perspective of a
    // command, we must build an "optoin" for it
    const subCommandDefn = {
        command: {
            ...{
                type: String,
                group: "subCommand",
                defaultOption: true,
            },
            ...(cmd.greedy ? { multiple: true } : {}),
        },
    };
    const greedyCommandDefn = {
        argv: {
            type: String,
            group: "argv",
            defaultOption: true,
            multiple: true,
        },
    };
    // we will then combine this with global options and as well as pickup the sub command
    // if the command defines sub-commands
    const optDefn = cmd.subCommands
        ? { ...index_1.globalOptions, ...subCommandDefn, ...cmd.options }
        : { ...index_1.globalOptions, ...cmd.options, ...(cmd.greedy ? greedyCommandDefn : {}) };
    // the options will be parsed into `local`, `global`, and `argv` categories
    // in a few cases there may also be `l2` and then anything which is not
    // known about will be dropped into `_unknown`.
    const { global, local, _unknown, subCommand, argv } = command_line_args_1.default(index_1.convertOptionsToArray(optDefn), {
        argv: incomingArgv,
        partial: true,
    });
    // opts come from both "local" and "global" options
    const opts = { ...(global ? global : {}), ...(local ? local : {}) };
    return {
        subCommand: subCommand ? (cmd.greedy ? subCommand.command[0] : subCommand.command) : undefined,
        argv: cmd.greedy ? (subCommand ? subCommand.slice(1) || [] : argv.argv || []) : [],
        raw: incomingArgv,
        opts,
        unknown: _unknown || [],
    };
}
exports.parseCmdArgs = parseCmdArgs;
