"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.proxyToPackageManager = void 0;
const async_shelljs_1 = require("async-shelljs");
const chalk_1 = __importDefault(require("chalk"));
const core_1 = require("./index");
const interactive_1 = require("../interactive/index");
const observations_1 = require("../observations/index");
const npm_1 = require("../npm/index");
const NON_PROXY = new Set(["install", "outdated", "update", "why"]);
async function proxyToPackageManager(cmd, observations, argv) {
    // can't continue without package.json
    if (!observations.has("packageJson")) {
        console.log(chalk_1.default `- ${"\uD83D\uDE32" /* shocked */} the {green ${cmd}} command is only meant to used in the root of NodeJS which has a {blue package.json} file in it.\n`);
        process.exit();
    }
    const pkgManager = await observations_1.determinePackageManager(observations, true);
    if (pkgManager) {
        let pkgCmd;
        let isScriptCmd = false;
        switch (cmd) {
            case "install":
                pkgCmd =
                    pkgManager === "yarn"
                        ? "yarn"
                        : `${pkgManager} install${argv ? " " + argv.join(" ") : ""}`;
                break;
            case "outdated":
            case "upgrade":
            case "why":
                pkgCmd = `${pkgManager} ${cmd}${argv ? " " + argv.join(" ") : ""}`;
                break;
            default:
                isScriptCmd = true;
                pkgCmd = `${pkgManager === "yarn"
                    ? `yarn ${cmd}${argv ? "" + argv.join(" ") : ""}`
                    : `${pkgManager} run ${cmd}${argv ? " " + argv.join(" ") : ""}`}`;
        }
        if (NON_PROXY.has(cmd)) {
            console.log(chalk_1.default `{gray - we detected use of the {blue ${pkgManager}} in this repo and will {italic proxy} "${cmd}" to: {blue ${pkgCmd}}}\n`);
        }
        else {
            console.log(chalk_1.default `{gray - the primary utility of the {italic ${cmd}} command is when paired with a Serverless project}`);
            if (isScriptCmd && !npm_1.hasScript(cmd)) {
                console.log(chalk_1.default `{gray - we {italic would} proxy this as {blue ${pkgCmd}} but you don't have "${cmd}" defined in your scripts section.}\n`);
                process.exit();
            }
            console.log(chalk_1.default `{gray - since this project is not we will instead just proxy {blue ${pkgCmd}} for you}\n`);
        }
        async_shelljs_1.exec(pkgCmd, {
            env: { ...process.env, TERM: "xterm-256color", FORCE_COLOR: "true" },
            timeout: 5000,
        });
    }
    else {
        if (!NON_PROXY.has(cmd)) {
            console.log(`- The "${cmd}" command will be used in Serverless projects but otherwise proxies the command to your package manager of choice. `);
        }
        console.log(chalk_1.default `- we can not currently tell {italic which} package manager you're using.`);
        const answer = await interactive_1.askListQuestion("Would you like save the package manager to this repo in a config file?", ["not now, thanks", "npm", "pnpm", "yarn"]);
        if (answer !== "not now, thanks") {
            core_1.saveToProjectConfig("general", { pkgManager: answer });
        }
    }
}
exports.proxyToPackageManager = proxyToPackageManager;
