"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveToProjectConfig = exports.saveToUserConfig = void 0;
const core_1 = require("./index");
const deepmerge_1 = __importDefault(require("deepmerge"));
/**
 * **saveToUserConfig**
 *
 * updates the configuration to a _section_ which is either a command or to
 * the `general` section for shared meta-data. The value passed in is
 * deep copied with the current value to ensure it is non-destructive.
 */
async function saveToUserConfig(section, updatedProps) {
    let config = core_1.getUserConfig();
    if (!config.userConfig) {
        config = { kind: "user", userConfig: true, general: {} };
    }
    const current = config[section] || {};
    const merged = deepmerge_1.default(current, updatedProps);
    const newConfig = { ...config, [section]: merged };
    core_1.writeConfig(newConfig, "user");
}
exports.saveToUserConfig = saveToUserConfig;
/**
 * **saveToUserConfig**
 *
 * updates the configuration to a _section_ which is either a command or to
 * the `general` section for shared meta-data. The value passed in is
 * deep copied with the current value to ensure it is non-destructive.
 */
async function saveToProjectConfig(section, updatedProps) {
    let config = core_1.getProjectConfig();
    if (!config.projectConfig) {
        config = { kind: "project", projectConfig: true, general: {} };
    }
    const current = config[section] || {};
    const merged = deepmerge_1.default(current, updatedProps);
    const newConfig = { ...config, [section]: merged };
    core_1.writeConfig(newConfig, "project");
}
exports.saveToProjectConfig = saveToProjectConfig;
