"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.finalizeCommandDefinition = void 0;
const _types_1 = require("../../../@types/index");
const core_1 = require("../index");
/**
 * Gets _finalized_ meta information about the specific functions where being
 * _finalized_ indicates that dynamic values have been resolved to static values
 * by passing in the _observervations_ and parsed _options_ available at this time
 */
function finalizeCommandDefinition(cmdDefn, 
/** all known observations available at this time */
observations, 
/** any/all parsed options available at this time */
options = {}) {
    const isGlobal = cmdDefn ? false : true;
    // description
    const d1 = _types_1.isDynamicCommandDefinition(cmdDefn.description)
        ? cmdDefn.description(observations, options)
        : cmdDefn.description;
    const description = _types_1.isCommandDescriptor(d1) ? (isGlobal ? d1.short : d1.complete) : d1;
    // commands
    const subCommands = _types_1.isDynamicCommandDefinition(cmdDefn.subCommands)
        ? cmdDefn.subCommands(observations, options)
        : cmdDefn.subCommands;
    return {
        kind: cmdDefn.kind,
        handler: cmdDefn.handler,
        syntax: cmdDefn.syntax || `dd ${cmdDefn.kind}${cmdDefn.subCommands ? " <cmd>" : ""} [options]`,
        description,
        subCommands,
        options: { ...cmdDefn.options, ...core_1.globalOptions },
        hiddenCommand: false,
    };
}
exports.finalizeCommandDefinition = finalizeCommandDefinition;
