"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readFile = void 0;
const fs_1 = require("fs");
const filesExist_1 = require("../existance/filesExist");
const helpers_1 = require("../helpers/index");
/**
 * Reads a file from the filesystem and returns as a string.
 *
 * Errors:
 *  - `read-file/unknown`
 *  - _if the file doesn't exist, will return_ `undefined`
 *
 * Where possible, use the following functions to be explicit about the
 * base directory you are intending:
 *   - `libraryDirectory()`,
 *   - `homeDirectory()`,
 *   - `currentDirectory()`
 *
 * If, however, the filename starts with `~/` or `./` the appropriate base
 * will be deduced as well.
 */
function readFile(filename) {
    filename = helpers_1.interpolateFilePath(filename);
    return filesExist_1.filesExist(filename) ? fs_1.readFileSync(filename, { encoding: "utf-8" }) : undefined;
}
exports.readFile = readFile;
