"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeFile = void 0;
const fs_1 = require("fs");
const errors_1 = require("../../../errors/index");
const existance_1 = require("../existance/index");
const interpolateFilepath_1 = require("../helpers/interpolateFilepath");
/**
 * Attempts to remove a file.
 *
 * Errors:
 * - `removal-failed/does-not-exist`
 * - `removal-failed/not-file`
 * - `removal-failed/other`
 *
 * Where possible, use the following functions to be explicit about the
 * base directory you are intending:
 *   - `libraryDirectory()`,
 *   - `homeDirectory()`,
 *   - `currentDirectory()`
 *
 * If, however, the filename starts with `~/` or `./` the appropriate base
 * will be deduced as well.
 */
function removeFile(filename) {
    filename = interpolateFilepath_1.interpolateFilePath(filename);
    if (!existance_1.fileExists(filename)) {
        throw new errors_1.DevopsError(`Attempt to remove a file -- ${filename} -- which does not exist!`, "removal-failed/does-not-exist");
    }
    const stat = fs_1.lstatSync(filename);
    if (!stat.isFile()) {
        throw new errors_1.DevopsError(`Can not remove the file "${filename}" as it is not a file!`, "removal-failed/not-file");
    }
    try {
        fs_1.rmSync(filename);
    }
    catch (error) {
        throw new errors_1.DevopsError(`Problem encountered trying to remove file "${filename}": ${error.message}`, "removal-failed/other");
    }
}
exports.removeFile = removeFile;
