"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.filesExist = void 0;
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = __importDefault(require("path"));
/**
 * Checks all the files to see if they exist in the file system.
 * If none do then it returns false, if some do then it returns
 * an array of those which _do_ exist.
 *
 * @param files the files to be checked for existance
 */
function filesExist(...files) {
    const exists = [];
    for (let f of files) {
        if (![".", "/", "~"].includes(f.slice(0, 1))) {
            f = path_1.default.posix.join(process.cwd(), f);
        }
        if (f.slice(0, 1) === "~") {
            f = path_1.default.posix.join(os_1.homedir(), f.slice(1));
        }
        if (fs_1.existsSync(f)) {
            exists.push(f);
        }
    }
    return exists.length > 0 ? exists : false;
}
exports.filesExist = filesExist;
