"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.filesInfo = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const errors_1 = require("../../errors/index");
/**
 * Get's file info from an array of files (using Node's `stat` operation).
 *
 * @param files the list of files to **stat**. The files will automatically
 * be associated with the current working directory unless the filenames start
 * with a `/`.
 */
function filesInfo(...files) {
    let rememberFile;
    try {
        return files.reduce((agg, filePath) => {
            rememberFile = filePath;
            const stats = fs_1.statSync(filePath.slice(0, 1) !== "/" ? path_1.default.join(process.cwd(), filePath) : filePath);
            const pathParts = filePath.split("/");
            const file = pathParts.pop() || "";
            const filepath = pathParts.slice(0, -1).join("/");
            const nameParts = file.split(".");
            const fileName = nameParts.slice(0, -1).join(".");
            const extension = nameParts.pop() || "";
            agg.push({ filePath, fileName, file, path: filepath, extension, stats });
            return agg;
        }, []);
    }
    catch (error) {
        throw new errors_1.DevopsError(`Attempt to get info/stat from the file "${rememberFile}" [ ${path_1.default.join(process.cwd(), rememberFile || "")} ] failed [ call included request for ${files.length} files ]: ${error.message}`, "do-devops/filesInfo");
    }
}
exports.filesInfo = filesInfo;
