"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.symlinks = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const directoryFiles_1 = require("./directoryFiles");
/**
 * **symlinks**
 *
 * Given a specified directory, this function will return an array of
 * files and folders which are symlinks. If you wish only files or folders,
 * you can specify this in the optional _filter_ parameter.
 */
function symlinks(dir, filter) {
    return directoryFiles_1.directoryFiles(dir)
        .filter((f) => {
        if (!f.stats.isSymbolicLink()) {
            return false;
        }
        if (!filter) {
            return true;
        }
        return filter === "only-dirs" ? f.stats.isDirectory() : !f.stats.isDirectory();
    })
        .map((lnk) => {
        const fullPath = path_1.default.posix.join(dir, lnk.file);
        const linkTo = fs_1.readlinkSync(fullPath, { encoding: "utf-8" });
        return { ...lnk, linkTo };
    });
}
exports.symlinks = symlinks;
