"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPackageJson = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const destr_1 = __importDefault(require("destr"));
const packageJsonCache_1 = require("./cache/packageJsonCache");
const errors_1 = require("../../../errors/index");
const file_1 = require("../../file/index");
/**
 * **getPackageJson**
 *
 * Returns the `package.json` of the local repo as a typed object, if the file
 * doesn't exist in the CWD -- or passed in override -- then it will return
 * `false`.
 *
 * Note: _will put this file into a saved cache for other package json operations
 * (which is only in memory, not persisted); similarly it will look for all requests
 * in cache before file or network operations_
 */
function getPackageJson(pathOverride) {
    // look in cache first
    const p = packageJsonCache_1.getPackageJsonfromCache(pathOverride);
    if (p) {
        return p;
    }
    const filename = path_1.default.join(pathOverride?.replace("package.json", "") || process.cwd(), "package.json");
    if (!file_1.fileExists(filename)) {
        throw new errors_1.DevopsError(`Attempt to get package.json [${filename}] file failed`, "not-ready/missing-package-json");
    }
    const pj = destr_1.default(fs_1.default.readFileSync(filename, { encoding: "utf-8" }));
    packageJsonCache_1.cacheLocalPackageJson(pj, pathOverride);
    return pj;
}
exports.getPackageJson = getPackageJson;
