"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pkgDepsInTable = void 0;
const chalk_1 = __importDefault(require("chalk"));
const ui_1 = require("../ui/index");
const convertDepDictionaryToArray_1 = require("./convertDepDictionaryToArray");
const index_1 = require("./index");
function formatDependencies(deps) {
    return deps.map((dep) => chalk_1.default `{bold ${dep.name}} [{dim ${dep.version} }]`);
}
/**
 * Produces a tabular view of deps where columns are
 * Deps, Dev Deps, Peer Deps, Optional Deps. Only the
 * columns which have data will be shown.
 */
function pkgDepsInTable(opts = {}) {
    const { dependencies, devDependencies, optionalDependencies, peerDependencies, } = index_1.getPackageJson();
    const deps = [
        { name: "Dependencies", data: opts.ignoreDeps ? undefined : dependencies },
        { name: "Dev Deps", data: opts.ignoreDevDeps ? undefined : devDependencies },
        { name: "Optional Deps", data: opts.ignoreOptionalDeps ? undefined : optionalDependencies },
        { name: "Peer Deps", data: opts.ignorePeerDeps ? undefined : peerDependencies },
    ]
        .filter((i) => i.data)
        .map((i) => ({
        name: i.name,
        data: formatDependencies(convertDepDictionaryToArray_1.convertDepDictionaryToArray(i.data)),
    }));
    const columns = deps.map((i) => i.name);
    const max = Math.max(...deps.map((d) => d.data.length));
    const data = [];
    for (let idx = 0; idx < max; idx++) {
        const row = {};
        for (const col of columns) {
            const datum = deps.find((c) => c.name === col)?.data || [];
            row[col] = datum[idx] ? datum[idx] : "";
        }
        data.push(row);
    }
    return ui_1.toTable(data, ...columns);
}
exports.pkgDepsInTable = pkgDepsInTable;
