"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineCredentials = void 0;
const aws_1 = require("../aws/index");
const determineProfile_1 = require("./determineProfile");
/**
 * **determineCredentials**
 *
 * Determines -- based on the environment and passed in options -- what
 * the right AWS _profile_ is and then returns the profile
 * along with the user's credentials.
 *
 * If the _profile_ can not be determined then this function returns `false`,
 * but if it can figure out a profile _name_ but the profile doesn't exist
 * in the user's `~/.aws/credentials` file, it will throw an error.
 *
 * **Errors:**
 * - `do-devops/invalid-profile-name`
 * - `do-devops/no-credentials-file`
 * - `do-devops/invalid-aws-profile` - this is very unlikely
 */
async function determineCredentials(opts) {
    const profile = await determineProfile_1.determineProfile(opts);
    if (!profile) {
        return false;
    }
    const credentials = await aws_1.getAwsProfile(profile);
    const region = credentials.region || opts.region;
    return region
        ? {
            credentials: aws_1.convertProfileToApiCredential(credentials),
            profile,
            region,
        }
        : { credentials: aws_1.convertProfileToApiCredential(credentials), profile };
}
exports.determineCredentials = determineCredentials;
