"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineLinter = void 0;
const npm_1 = require("../npm/index");
const destr_1 = __importDefault(require("destr"));
const file_1 = require("../file/index");
/**
 * Looks for linters by interogating the `package.json` as well as looking for
 * configuration files.
 *
 * The two linters we're looking for are `eslint` and `tslint`. The return type
 * will be set to false if it looks like they're not present but if they _are_
 * present we will send back the configuration file as text if it can be found.
 */
function determineLinter() {
    const observations = new Set();
    let eslint = false;
    let tslint = false;
    let prettier = false;
    const pkg = npm_1.getPackageJson();
    if (pkg) {
        if (npm_1.hasDevDependency("eslint")) {
            observations.add("eslint");
            if (npm_1.hasDevDependency("@typescript-eslint/eslint-plugin")) {
                observations.add("typescriptEslintPlugin");
            }
            if (npm_1.hasDevDependency("@typescript-eslint/parser")) {
                observations.add("typescriptEslintParser");
            }
            if (pkg.eslintConfig) {
                observations.add("eslintConfig");
                eslint = { config: destr_1.default(pkg.eslintConfig), filename: "package.json" };
            }
            else {
                for (const filename of [".eslintrc", ".eslintrc.js", ".eslintrc.ts"]) {
                    const fileContent = file_1.readFile(filename);
                    eslint = { config: destr_1.default(fileContent), filename };
                }
            }
        }
        if (npm_1.hasDevDependency("tslint")) {
            observations.add("tslint");
            const fileContent = file_1.readFile("tslint.json");
            tslint = fileContent ? { config: destr_1.default(fileContent), filename: "tslint.json" } : true;
        }
        if (npm_1.hasDevDependency("prettier")) {
            observations.add("prettier");
            if (file_1.fileExists(".prettierrc")) {
                prettier = file_1.readFile(".prettierrc") || false;
            }
        }
        if (npm_1.hasDevDependency("eslint-prettier-plugin")) {
            observations.add("eslintPrettierPlugin");
        }
    }
    return { observations, eslint, tslint, prettier };
}
exports.determineLinter = determineLinter;
