"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineProfile = void 0;
const serverless_1 = require("../serverless/index");
const _types_1 = require("../../@types/index");
const core_1 = require("../core/index");
const aws_1 = require("../aws/index");
/** ensure that during one CLI operation we cache this value */
let profile;
/**
 * Based on CLI, serverless info, and config files, determine which
 * AWS `profile` the serverless command should leverage for credentials
 * as well as -- optionally -- the _region_. Sequence is:
 *
 * - look at `CLI switches` for explicit statement about profile
 * - if serverlessYaml, use serverless config to determine
 * - look at the global default for the `project configuration`
 * - look at the global default for the `user configuration`
 * - if "interactive", then ask user for profile name from available options
 */
async function determineProfile(opts, observations = new Set()) {
    if (opts.profile) {
        return opts.profile;
    }
    if (observations.has("serverlessTs")) {
        // TODO : transpile to JS and import
    }
    if (observations.has("serverlessYml")) {
        const serverlessYaml = await serverless_1.getServerlessYaml();
        if (serverlessYaml.provider.profile) {
            return serverlessYaml.provider.profile;
        }
    }
    else {
        console.log({ observations });
    }
    let doConfig;
    try {
        doConfig = await core_1.getIntegratedConfig();
        if (_types_1.configIsReady(doConfig) && doConfig.general?.defaultAwsProfile) {
            profile = doConfig.general.defaultAwsProfile;
        }
    }
    catch { }
    if (!profile && opts.interactive) {
        try {
            profile = await aws_1.askForAwsProfile({ exitOnError: false });
            // TODO: what should be done with this?
            // const _saveForNextTime = await askToSaveConfig("general.defaultAwsProfile", profile);
        }
        catch { }
    }
    return profile ? profile : false;
}
exports.determineProfile = determineProfile;
