"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineRegion = void 0;
/* eslint-disable unicorn/no-useless-undefined */
const chalk_1 = __importDefault(require("chalk"));
const lodash_1 = require("lodash");
const index_1 = require("./index");
const aws_1 = require("../aws/index");
const serverless_1 = require("../serverless/index");
const core_1 = require("../core/index");
const _types_1 = require("../../@types/index");
/**
 * Determines the appropriate AWS `region` to point at based on CLI switches/options,
 * the Serverless configuration, and the global `do` config defaults.
 *
 * If an appropriate region can't be determined this function will return `false`.
 */
async function determineRegion(opts = {}, observations = new Set()) {
    const config = core_1.getIntegratedConfig();
    let region = opts.region || process.env.AWS_REGION;
    if (!region && observations.has("serverlessYml")) {
        try {
            region = lodash_1.get(await serverless_1.getServerlessYaml(), "provider.region", undefined);
        }
        catch { }
    }
    if (!region) {
        region = lodash_1.get(config, "global.defaultAwsRegion", undefined);
    }
    // attempt to find it in the credentials file for the given profile
    if (!region) {
        const profileName = await index_1.determineProfile(opts || {});
        if (profileName) {
            const profile = await aws_1.getAwsProfile(profileName);
            if (profile && profile.region) {
                region = profile.region;
            }
        }
    }
    // USER Config is last resort
    if (!region) {
        const userConfig = core_1.getUserConfig();
        if (_types_1.configIsReady(userConfig) && userConfig.general?.defaultAwsRegion) {
            if (!opts.quiet) {
                console.log(chalk_1.default `{bold - AWS region has been resolved using the User's config ${"\uD83D\uDC40" /* eyeballs */}}. This is the source of "last resort" but may be intended.`);
            }
            region = userConfig.general.defaultAwsRegion;
        }
    }
    return region;
}
exports.determineRegion = determineRegion;
