"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getObservations = void 0;
const file_1 = require("../file/index");
const npm_1 = require("../npm/index");
const index_1 = require("./index");
/**
 * Gets the core "observations" about the current directory.
 */
function getObservations() {
    let observations = new Set();
    let pkgJson;
    try {
        pkgJson = npm_1.getPackageJson();
    }
    catch { }
    if (pkgJson) {
        observations.add("packageJson");
        // TS
        if (npm_1.hasDevDependency("typescript")) {
            observations.add("typescript");
        }
        if (npm_1.hasDevDependency("ttypescript")) {
            observations.add("ttypescript");
        }
        if (npm_1.hasDevDependency("typescript-transform-paths")) {
            observations.add("typescriptTransformPaths");
        }
        // Bundlers
        if (npm_1.hasDevDependency("rollup")) {
            observations.add("rollup");
        }
        if (npm_1.hasDevDependency("webpack")) {
            observations.add("webpack");
        }
        if (npm_1.hasDevDependency("vite")) {
            observations.add("vite");
        }
        if (npm_1.hasDevDependency("esbuild")) {
            observations.add("esbuild");
        }
        // DBs
        if (npm_1.hasDependency("firebase-admin") || npm_1.hasDependency("@firebase/app")) {
            observations.add("firebase");
        }
        if (npm_1.hasDependency("firemodel")) {
            observations.add("firemodel");
        }
        if (npm_1.hasDependency("universal-fire")) {
            observations.add("universalFire");
        }
        if (npm_1.hasDependency("supabase")) {
            observations.add("supabase");
        }
        // Testing
        if (npm_1.hasDevDependency("mocha")) {
            observations.add("mocha");
        }
        if (npm_1.hasDevDependency("jest")) {
            observations.add("jest");
        }
        if (npm_1.hasDevDependency("uvu")) {
            observations.add("uvu");
        }
        // Serverless
        if (npm_1.hasDevDependency("serverless")) {
            observations.add("serverlessFramework");
        }
        if (file_1.fileExists("./serverless.yml")) {
            observations.add("serverlessYml");
        }
        if (file_1.fileExists("./serverless.ts")) {
            observations.add("serverlessTs");
        }
        if (npm_1.hasDevDependency("webpack-plugin")) {
            observations.add("serverlessWebpackPlugin");
        }
        // https://www.serverless.com/plugins/serverless-sam
        if (npm_1.hasDevDependency("serverless-sam")) {
            observations.add("serverlessSamPlugin");
        }
        // needed for serverless devops handoffs
        if (npm_1.hasDevDependency("ts-node")) {
            observations.add("tsNode");
        }
        // package manager
        let pm = 0;
        if (file_1.fileExists(npm_1.PKG_MGR_LOCK_FILE_LOOKUP.yarn)) {
            pm++;
            observations.add("yarn");
        }
        if (file_1.fileExists(npm_1.PKG_MGR_LOCK_FILE_LOOKUP.pnpm)) {
            pm++;
            observations.add("pnpm");
        }
        if (file_1.fileExists(npm_1.PKG_MGR_LOCK_FILE_LOOKUP.npm)) {
            pm++;
            observations.add("npm");
        }
        if (pm > 1) {
            observations.add("packageManagerConflict");
        }
        if (npm_1.hasMainExport()) {
            observations.add("cjs");
        }
        if (npm_1.hasModuleExport()) {
            observations.add("esm");
        }
        if (npm_1.hasTypingsExport()) {
            observations.add("typings");
        }
        // linters
        const lint = index_1.determineLinter();
        observations = new Set([...observations, ...lint.observations]);
    }
    return observations;
}
exports.getObservations = getObservations;
