"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isServerless = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const npm_1 = require("../npm/index");
const getServerlessYaml_1 = require("../serverless/getServerlessYaml");
/**
 * **isServerless**
 *
 * returns a set of flags indicating whether it appears the serverless framework
 * is being used in this repo
 */
async function isServerless() {
    const hasServerlessConfig = fs_1.default.existsSync(path_1.default.join(process.cwd(), "serverless.yml"));
    let slsConfig;
    try {
        slsConfig = await getServerlessYaml_1.getServerlessYaml();
    }
    catch { }
    const pkgJson = npm_1.getPackageJson();
    const hasAsDevDep = pkgJson
        ? Object.keys(pkgJson.devDependencies || {}).includes("serverless")
        : false;
    const isUsingTypescriptMicroserviceTemplate = fs_1.default.existsSync(path_1.default.join(process.cwd(), "serverless-config/config.ts"));
    const hasProviderSection = slsConfig && slsConfig.provider ? true : false;
    const configIsParsable = hasServerlessConfig && slsConfig ? true : false;
    return hasServerlessConfig || hasAsDevDep || isUsingTypescriptMicroserviceTemplate
        ? {
            hasServerlessConfig,
            hasAsDevDep,
            isUsingTypescriptMicroserviceTemplate,
            hasProviderSection,
            configIsParsable,
        }
        : false;
}
exports.isServerless = isServerless;
