"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWebpackEntryDictionaries = exports.useKey = void 0;
const path_1 = __importDefault(require("path"));
const file_1 = require("../../file/index");
function useKey(key) {
    return (agg, curr) => {
        agg[curr.fn] = curr[key];
        return agg;
    };
}
exports.useKey = useKey;
/**
 * Webpack can create named multiple entry points if the `entry` parameter
 * is passed a dictionary where the key is the module name (in Serverless
 * this would be the handler's name) and the value is then the full path to
 * the file.
 *
 * This function will, given a path to the source typescript files, produce
 * two dictionaries:
 *
 * 1. `webpack.ts-entry-points.json` - a dictionary that points to the handler's
 * typescript source
 * 2. `webpack.js-entry-points.json` - a dictionary that points to webpack's outputted
 * javascript files
 *
 * If you are using the `serverless-webpack` plugin you should use the former, if you
 * are managing the webpack process yourself then the latter is likely more appropriate.
 */
async function createWebpackEntryDictionaries(handlerFns) {
    const data = handlerFns.reduce((agg, f) => {
        const fn = (f.split("/").pop() || "").replace(".ts", "");
        const tsPath = "./" + path_1.default.relative(process.cwd(), f);
        const jsPath = (tsPath.split("/").pop() || "")
            .replace(/(.*)/, ".webpack/$1")
            .replace(".ts", ".js");
        return [...agg, { fn, tsPath, jsPath }];
    }, []);
    await Promise.all([
        file_1.write("webpack.ts-entry-points.json", data.reduce(useKey("tsPath"), {})),
        file_1.write("webpack.js-entry-points.json", data.reduce(useKey("jsPath"), {})),
    ]);
}
exports.createWebpackEntryDictionaries = createWebpackEntryDictionaries;
