"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAccountInfoFromServerlessYaml = void 0;
const errors_1 = require("../../errors/index");
const getServerlessYaml_1 = require("./getServerlessYaml");
/**
 * Gets the `accountInfo` from the `serverless.yml` file if
 * possible. If not it returns an empty object.
 */
async function getAccountInfoFromServerlessYaml() {
    try {
        const config = await getServerlessYaml_1.getServerlessYaml();
        const info = {
            name: typeof config.service === "string" ? config.service : config.service.name,
            accountId: config?.custom?.accountId,
            region: config.provider.region,
            profile: config.provider.profile,
            pluginsInstalled: config.plugins || [],
            // tracing: (config as any).tracing
        };
        if (config?.custom?.logForwarding) {
            info.logForwarding = config.custom.logForwarding.destinationARN;
        }
        return info;
    }
    catch (error) {
        throw new errors_1.DevopsError(`Problems getting serverless.yml's account info: ${error.message}`, "serverless-framework/account-info");
    }
}
exports.getAccountInfoFromServerlessYaml = getAccountInfoFromServerlessYaml;
