"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLambdaFunctions = void 0;
const aws_sdk_1 = require("aws-sdk");
const aws_1 = require("../aws/index");
const observations_1 = require("../observations/index");
const errors_1 = require("../../errors/index");
/**
 * **getLambdaFunctions**
 *
 * Returns an array of lambda functions for a given AWS _profile_ and
 * _region_.
 *
 * The options hash allows you to state explicitly which profile/region but if you
 * skip this then an attempt will be made to figure it out based on
 * ENV variables and files in the working directory.
 */
async function getLambdaFunctions(opts = {}) {
    const region = opts.region ? opts.region : await observations_1.determineRegion(opts);
    const profileName = await observations_1.determineProfile(opts);
    if (!profileName) {
        throw new errors_1.DevopsError("Could not determine the AWS Profile to use!", "not-ready/missing-profile");
    }
    const profile = aws_1.convertProfileToApiCredential(await aws_1.getAwsProfile(profileName));
    const lambda = new aws_sdk_1.Lambda({
        apiVersion: "2015-03-31",
        region,
        ...profile,
    });
    const fns = await lambda.listFunctions().promise();
    return fns.Functions || [];
}
exports.getLambdaFunctions = getLambdaFunctions;
