"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMicroserviceConfig = void 0;
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const errors_1 = require("../../errors/index");
const async_shelljs_1 = require("async-shelljs");
/**
 * Gets the typescript configuration file for serverless
 * projects which use the `typescript-microservice` yeoman
 * template and generates a `serverless.yml` file from it.
 */
async function getMicroserviceConfig(accountInfo) {
    const cliFile = path_1.default.join(process.env.PWD || "", "serverless-config", "build.ts");
    try {
        const config = await async_shelljs_1.asyncExec(`yarn ts-node ${cliFile} '${JSON.stringify(accountInfo)}'`, {
            silent: true,
        });
        return config;
    }
    catch (error) {
        console.log(chalk_1.default `{yellow - failed executing ${cliFile}}`);
        throw new errors_1.DevopsError(`Problem getting the microservice config file [ ${cliFile} ]: ${error.message}`, "devops/missing-config");
    }
}
exports.getMicroserviceConfig = getMicroserviceConfig;
