"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getServerlessBuildConfiguration = void 0;
const typed_mapper_1 = require("typed-mapper");
const errors_1 = require("../../errors/index");
const serverless_1 = require("./index");
const npm_1 = require("../npm/index");
const yeoman_1 = require("../yeoman/index");
function transformYeomanFormat(input) {
    return typed_mapper_1.TypedMapper.map({
        name: "serviceName",
        accountId: "awsAccount",
        profile: "awsProfile",
        region: "awsRegion",
        devDependencies: () => [],
        pluginsInstalled: () => [],
    }).convertObject(input);
}
/**
 * Will find the appropriate configuration information
 * for the serverless build process. Looking either in
 * the `serverless-config/account-info.yml` (deprecated)
 * or pulled from the Yeoman templates's `.yo-rc.json` file.
 *
 * If the info is not found in either location then it
 * will switch to interactive mode to get the data it
 * needs.
 */
async function getServerlessBuildConfiguration() {
    const modern = yeoman_1.getYeomanScaffolds().includes("generator-lambda-typescript");
    const pkg = npm_1.getPackageJson();
    if (!pkg) {
        throw new errors_1.DevopsError(`Attempt to build Serverless configuration failed as there is no package.json the current working directory!`, "not-ready/missing-package-json");
    }
    const knownAccountInfo = {
        ...(modern
            ? transformYeomanFormat(yeoman_1.getYeomanConfig())
            : await serverless_1.getAccountInfoFromServerlessYaml()),
        devDependencies: Object.keys(pkg.devDependencies || {}),
        pluginsInstalled: Object.keys(pkg.devDependencies || {}).filter((i) => i.startsWith("serverless-")),
    };
    const accountInfo = await serverless_1.askForAccountInfo(knownAccountInfo);
    return accountInfo;
}
exports.getServerlessBuildConfiguration = getServerlessBuildConfiguration;
