"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getServerlessYaml = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const errors_1 = require("../../errors/index");
const js_yaml_1 = require("js-yaml");
/**
 * Get the `serverless.yml` file in the root of the project
 */
async function getServerlessYaml() {
    const baseStructure = {
        functions: {},
        stepFunctions: { stateMachines: {} },
    };
    try {
        const fileContents = fs_1.default.readFileSync(path_1.default.join(process.cwd(), "serverless.yml"), {
            encoding: "utf-8",
        });
        const config = js_yaml_1.load(fileContents);
        return { ...baseStructure, ...config };
    }
    catch (error) {
        throw new errors_1.DevopsError(`Failure getting serverless.yml: ${error.message}`, error.name);
    }
}
exports.getServerlessYaml = getServerlessYaml;
