"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLayersFromPackageJson = void 0;
const npm_1 = require("../../npm/index");
const path_1 = __importDefault(require("path"));
const errors_1 = require("../../../errors/index");
/**
 * Introspects your dev dependencies for those which have `aws-layer`
 * or `aws-layer-meta` indicated as a **keyword**. From that it
 * constructs the meta information defined in `IAwsLayerMeta`.
 *
 * Note: this is a quick lookup method but will miss layers which were
 * not tagged appropriately in `package.json`.
 */
function getLayersFromPackageJson() {
    const pkg = npm_1.getPackageJson();
    if (!pkg) {
        throw new errors_1.DevopsError(`Attempt to read layers from package.json but file is missing!`, "not-ready/missing-package-json");
    }
    const devDeps = Object.keys(pkg.devDependencies || {});
    // get deps with appropriate tagging
    const pkgJsonFiles = devDeps.filter((d) => {
        const foreignPkg = npm_1.getPackageJson(path_1.default.join(process.cwd(), "node_modules", d));
        if (!foreignPkg) {
            throw new errors_1.DevopsError(`Attempt to get info on package info on "" requires that it be installed in the repo. Make sure to install deps before running this command.`, "not-ready/missing-dep");
        }
        const keywords = foreignPkg.keywords;
        return keywords ? keywords.includes("aws-layer-meta") || keywords.includes("aws-layer") : false;
    });
    return pkgJsonFiles
        .filter((i) => i)
        .reduce((agg, d) => {
        const meta = require(path_1.default.join(process.cwd(), "node_modules", d)).meta;
        const info = meta
            ? { ...meta, name: meta.name }
            : { name: d, namespace: "unknown", versions: [] };
        agg.push(info);
        return agg;
    }, []);
}
exports.getLayersFromPackageJson = getLayersFromPackageJson;
