"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.highlightFilepath = void 0;
/* eslint-disable unicorn/import-style */
const chalk_1 = __importDefault(require("chalk"));
/**
 * Uses `chalk` to present a nicely formatted
 * filepath and file where the file name itself is highlighted
 */
function highlightFilepath(fp, color = ["dim", "blueBright"], highlight = ["bold", "blueBright"]) {
    if (!Array.isArray(color)) {
        color = [undefined, color];
    }
    if (!Array.isArray(highlight)) {
        highlight = [undefined, highlight];
    }
    const [modifier, foreground] = color;
    const [highModifier, highForeground] = highlight;
    const parts = fp.split(/[/\\]/);
    const file = parts.pop();
    const path = parts.join("/").replace(/^(\S)/, "./$1");
    const filePath = modifier
        ? chalk_1.default `{${modifier} {${foreground} ${path + "/"}}}`
        : chalk_1.default `{${foreground} ${path + "/"}}`;
    const fileName = highModifier
        ? chalk_1.default `{${highModifier} {${highForeground} ${file}}}`
        : chalk_1.default `{${highForeground} ${file}}`;
    return `${filePath}${fileName}`;
}
exports.highlightFilepath = highlightFilepath;
